@@ -308,8 +308,19 @@ class Locale(object):
             'xkblayout': 'nl',
             'language': 'nl_NL',
         }),
+        ('nb_NO', {
+            'name': 'Norsk bokmål (Noreg)',
+            'layoutname': 'Nynorsk',
+            'locale': 'nb_NO.utf8',
+            'keymap': 'no-latin1',
+            'timezone': 'Europe/Oslo',
+            'dumpkeys_charset': '',
+            'consolefont': 'ter-v14n',
+            'xkblayout': 'no',
+            'language': 'nb',
+        }),
         ('nn_NO', {
-            'name': 'Nynorsk (Noreg)',
+            'name': 'Norsk nynorsk (Noreg)',
             'layoutname': 'Nynorsk',
             'locale': 'nn_NO.utf8',
             'keymap': 'no-latin1',
